@@ -1,6 +1,4 @@
-﻿__version__ = "0.1.0"
-
-from .download import (
+﻿from .download import (
     PreDownload,
     PreDownloadTask,
     PreDownloadModel,
@@ -14,13 +12,19 @@ from .download import (
 
     FileDownloader,
     FileDownload,
-    FileDownloadProgress
+    FileDownloadProgress,
 )
 
 from .paths import (
     Paths
 )
 
+from .models import (
+    SupportedSitesModel,
+    StringFilterModel,
+    HistoryModel
+)
+
 from .dialog_manager import (
     DialogManager
 )
