@@ -10,6 +10,7 @@ import pathlib
 import pickle
 import youtube_dl
 import atexit
+import urllib.request
 
 from .logger import create_logger
 from .settings import Settings
@@ -110,8 +111,8 @@ class PreDownload(QObject):
     @Slot(int)
     def handle_finished(self):
         if self.task.info:
-            if self.task.info["is_live"]:
-                self.status = "unsupported: livestream"
+            if "is_live" in self.task.info and self.task.info["is_live"]:
+                self.status = "ERROR: Unsupported: livestream"
                 self.updated.emit(str(self.id))
 
             else:
@@ -806,8 +807,9 @@ class DownloadModel(QAbstractListModel):
             return
 
         if self.downloads[row].running():
-            self.downloads[row].task.finished.connect(lambda: self.remove_download(self.downloads.index(self.downloads[row])))
-            self.downloads[row].pause()
+            removable_download = self.downloads[row]
+            removable_download.task.finished.connect(lambda: self.remove_download(self.downloads.index(removable_download)))
+            removable_download.pause()
             return
 
         self.beginRemoveRows(QModelIndex(), row, row)
@@ -858,6 +860,9 @@ class DownloadDuplicateChecker(object):
 
 
 class DownloadManager(QObject):
+    preDownloadRequest = Signal(str, arguments=["url"])
+    newDownload = Signal("QVariant", arguments=["download"])
+
     def __init__(self, config_path=None):
         super(DownloadManager, self).__init__(None)
         self.predownload_model = PreDownloadModel(config_path)
@@ -877,6 +882,7 @@ class DownloadManager(QObject):
             if predownload.status == "ready":
                 download = Download.fromPreDownload(predownload)
                 self.download_model.add_download(download)
+                self.newDownload.emit(PreDownload.pack(predownload))
                 download.start()
 
         self.predownload_model.remove("ready")
